EXPORTS
	??0RGenConAgentDialogServer@@QAE@XZ @ 1 NONAME ; public: __thiscall RGenConAgentDialogServer::RGenConAgentDialogServer(void)
	??1RGenConAgentDialogServer@@QAE@XZ @ 2 NONAME ; public: __thiscall RGenConAgentDialogServer::~RGenConAgentDialogServer(void)
	?Authenticate@RGenConAgentDialogServer@@QAEXAAVTDes16@@0HAAVTRequestStatus@@@Z @ 3 NONAME ; public: void __thiscall RGenConAgentDialogServer::Authenticate(class TDes16 &,class TDes16 &,int,class TRequestStatus &)
	?CancelAuthenticate@RGenConAgentDialogServer@@QAEXXZ @ 4 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelAuthenticate(void)
	?CancelDestroyPctNotification@RGenConAgentDialogServer@@QAEXXZ @ 5 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelDestroyPctNotification(void)
	?CancelIapConnection@RGenConAgentDialogServer@@QAEXXZ @ 6 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelIapConnection(void)
	?CancelLogin@RGenConAgentDialogServer@@QAEXXZ @ 7 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelLogin(void)
	?CancelModemAndLocationSelection@RGenConAgentDialogServer@@QAEXXZ @ 8 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelModemAndLocationSelection(void)
	?CancelQoSWarning@RGenConAgentDialogServer@@QAEXXZ @ 9 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelQoSWarning(void)
	?CancelReadPct@RGenConAgentDialogServer@@QAEXXZ @ 10 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelReadPct(void)
	?CancelReconnect@RGenConAgentDialogServer@@QAEXXZ @ 11 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelReconnect(void)
	?CancelWarnNewIapConnection@RGenConAgentDialogServer@@QAEXXZ @ 12 NONAME ; public: void __thiscall RGenConAgentDialogServer::CancelWarnNewIapConnection(void)
	?Close@RGenConAgentDialogServer@@QAEXXZ @ 13 NONAME ; public: void __thiscall RGenConAgentDialogServer::Close(void)
	?ClosePct@RGenConAgentDialogServer@@QAEXXZ @ 14 NONAME ; public: void __thiscall RGenConAgentDialogServer::ClosePct(void)
	?Connect@RGenConAgentDialogServer@@QAEHXZ @ 15 NONAME ; public: int __thiscall RGenConAgentDialogServer::Connect(void)
	?DestroyPctNotification@RGenConAgentDialogServer@@QAEXAAVTRequestStatus@@@Z @ 16 NONAME ; public: void __thiscall RGenConAgentDialogServer::DestroyPctNotification(class TRequestStatus &)
	?IapConnection@RGenConAgentDialogServer@@QAEXAAKABVTConnectionPrefs@@AAVTRequestStatus@@@Z @ 17 NONAME ; public: void __thiscall RGenConAgentDialogServer::IapConnection(unsigned long &,class TConnectionPrefs const &,class TRequestStatus &)
	?IapConnection@RGenConAgentDialogServer@@QAEXAAKABVTConnectionPrefs@@HAAVTRequestStatus@@@Z @ 18 NONAME ; public: void __thiscall RGenConAgentDialogServer::IapConnection(unsigned long &,class TConnectionPrefs const &,int,class TRequestStatus &)
	?Login@RGenConAgentDialogServer@@QAEXAAVTDes16@@0HAAVTRequestStatus@@@Z @ 19 NONAME ; public: void __thiscall RGenConAgentDialogServer::Login(class TDes16 &,class TDes16 &,int,class TRequestStatus &)
	?ModemAndLocationSelection@RGenConAgentDialogServer@@QAEXAAK0AAVTRequestStatus@@@Z @ 20 NONAME ; public: void __thiscall RGenConAgentDialogServer::ModemAndLocationSelection(unsigned long &,unsigned long &,class TRequestStatus &)
	?OpenPct@RGenConAgentDialogServer@@QAEHXZ @ 21 NONAME ; public: int __thiscall RGenConAgentDialogServer::OpenPct(void)
	?QoSWarning@RGenConAgentDialogServer@@QAEXAAHAAVTRequestStatus@@@Z @ 22 NONAME ; public: void __thiscall RGenConAgentDialogServer::QoSWarning(int &,class TRequestStatus &)
	?ReadPct@RGenConAgentDialogServer@@QAEXAAVTDes16@@AAVTRequestStatus@@@Z @ 23 NONAME ; public: void __thiscall RGenConAgentDialogServer::ReadPct(class TDes16 &,class TRequestStatus &)
	?Reconnect@RGenConAgentDialogServer@@QAEXAAHAAVTRequestStatus@@@Z @ 24 NONAME ; public: void __thiscall RGenConAgentDialogServer::Reconnect(int &,class TRequestStatus &)
	?StartDialogThread@@YAHXZ @ 25 NONAME ; int __cdecl StartDialogThread(void)
	?Version@RGenConAgentDialogServer@@QBE?AVTVersion@@XZ @ 26 NONAME ; public: class TVersion  __thiscall RGenConAgentDialogServer::Version(void)const 
	?WarnNewIapConnection@RGenConAgentDialogServer@@QAEXABVTConnectionPrefs@@HABVTDesC16@@AAHAAVTRequestStatus@@@Z @ 27 NONAME ; public: void __thiscall RGenConAgentDialogServer::WarnNewIapConnection(class TConnectionPrefs const &,int,class TDesC16 const &,int &,class TRequestStatus &)
	?WritePct@RGenConAgentDialogServer@@QAEHABVTDesC16@@@Z @ 28 NONAME ; public: int __thiscall RGenConAgentDialogServer::WritePct(class TDesC16 const &)
	?ThreadFunction@@YAHPAX@Z @ 29 NONAME ; public: int __cdecl ThreadFunction(void *)
	?AccessPointConnection@RGenConAgentDialogServer@@QAEXAAKHAAVTRequestStatus@@@Z @ 30 NONAME ; void RGenConAgentDialogServer::AccessPointConnection(unsigned long &, int, class TRequestStatus &)
	?CancelAccessPointConnection@RGenConAgentDialogServer@@QAEXXZ @ 31 NONAME ; void RGenConAgentDialogServer::CancelAccessPointConnection(void)
	?AccessPointConnection@RGenConAgentDialogServer@@QAEXAAKK0KAAVTRequestStatus@@@Z @ 32 NONAME ; void RGenConAgentDialogServer::AccessPointConnection(unsigned long &, unsigned long, unsigned long &, unsigned long, class TRequestStatus &)


